Learn R Programming

annotaR (version 0.1.1)

add_disease_links: Add disease association data

Description

Augments an annotaR object with disease association data from the OpenTargets platform.

Usage

add_disease_links(annotaR_object, score_threshold = 0.5)

Value

A new tibble with the original data joined with disease association columns (disease_name, association_score).

Arguments

annotaR_object

A tibble, typically from annotaR(), containing a 'gene' column with HGNC symbols.

score_threshold

Minimum association score (from 0 to 1) to include. Defaults to 0.5.

Examples

Run this code
# \donttest{
  annotaR(c("TP53", "EGFR")) %>%
    add_disease_links(score_threshold = 0.8)
# }

Run the code above in your browser using DataLab