Learn R Programming

annotaR (version 0.1.1)

add_drug_links: Add known drug association data

Description

Augments an annotaR object with known drug/compound data from the OpenTargets platform. This includes the drug name, type, mechanism of action, and clinical trial phase.

Usage

add_drug_links(annotaR_object)

Value

A new tibble with the original data joined with drug association columns (e.g., drug_name, drug_type, mechanism_of_action, phase).

Arguments

annotaR_object

A tibble, typically from annotaR(), containing a 'gene' column with HGNC symbols.

Examples

Run this code
# \donttest{
  annotaR(c("EGFR", "BRAF")) %>%
    add_drug_links()
# }

Run the code above in your browser using DataLab