Learn R Programming

annotaR (version 0.1.1)

add_go_terms: Add GO functional enrichment data

Description

Augments an annotaR object with functional enrichment data from g:Profiler. It performs a Gene Ontology (GO) analysis on the gene list and joins the results.

Usage

add_go_terms(annotaR_object, organism = "hsapiens", sources = c("GO:BP"), ...)

Value

A new tibble with the original 'gene' column joined with functional annotation columns (e.g., term_id, term_name, p_value, source).

Arguments

annotaR_object

A tibble, typically the output of annotaR(). Must contain a 'gene' column.

organism

The organism name to use for the query (e.g., "hsapiens"). Passed to gprofiler2::gost.

sources

A vector of data sources to query. Defaults to GO Biological Process. See gprofiler2::gost for options.

...

Additional parameters passed on to gprofiler2::gost.

Examples

Run this code
# \donttest{
  annotaR(c("TP53", "EGFR")) %>%
    add_go_terms()
# }

Run the code above in your browser using DataLab