powered by
Augments an annotaR object with disease association data from the OpenTargets platform.
add_disease_links(annotaR_object, score_threshold = 0.5)
A new tibble with the original data joined with disease association columns (disease_name, association_score).
A tibble, typically from annotaR(), containing a 'gene' column with HGNC symbols.
annotaR()
Minimum association score (from 0 to 1) to include. Defaults to 0.5.
# \donttest{ annotaR(c("TP53", "EGFR")) %>% add_disease_links(score_threshold = 0.8) # }
Run the code above in your browser using DataLab