powered by
Augments an annotaR object with functional enrichment data from g:Profiler. It performs a Gene Ontology (GO) analysis on the gene list and joins the results.
add_go_terms(annotaR_object, organism = "hsapiens", sources = c("GO:BP"), ...)
A new tibble with the original 'gene' column joined with functional annotation columns (e.g., term_id, term_name, p_value, source).
A tibble, typically the output of annotaR(). Must contain a 'gene' column.
annotaR()
The organism name to use for the query (e.g., "hsapiens"). Passed to gprofiler2::gost.
gprofiler2::gost
A vector of data sources to query. Defaults to GO Biological Process. See gprofiler2::gost for options.
Additional parameters passed on to gprofiler2::gost.
# \donttest{ annotaR(c("TP53", "EGFR")) %>% add_go_terms() # }
Run the code above in your browser using DataLab